# Changelog

## Version 0.0.7
- change to .index property to support multi-dimensional CellArrayFrame objects.

## Version 0.0.1 - 0.0.6

- Initial release of the classes with tests and documentation.
- Fixed issues with subsetting and dataframe-like accessors.
- Add `index` and its alias `rownames` methods.
